"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validatePatchIdentityOutput = exports.validatePatchIdentityInput = exports.validateGetIdentityOutput = exports.validateGetIdentityInput = exports.validateDeleteUsersByUsernameRolesByRoleNameOutput = exports.validateDeleteUsersByUsernameRolesByRoleNameInput = exports.validatePutUsersByUsernameRolesByRoleNameOutput = exports.validatePutUsersByUsernameRolesByRoleNameInput = exports.validateDeleteUsersByUsernameOutput = exports.validateDeleteUsersByUsernameInput = exports.validatePatchUsersByUsernameOutput = exports.validatePatchUsersByUsernameInput = exports.validateGetUsersByUsernameOutput = exports.validateGetUsersByUsernameInput = exports.validatePostUsersOutput = exports.validatePostUsersInput = exports.validateGetUsersOutput = exports.validateGetUsersInput = exports.validatePostDeviceAuthenticationTokenOutput = exports.validatePostDeviceAuthenticationTokenInput = exports.validatePostLogoutOutput = exports.validatePostLogoutInput = exports.validatePostLoginOutput = exports.validatePostLoginInput = exports.validateGetAuthOutput = exports.validateGetAuthInput = void 0;
const basicValidation_1 = require("./basicValidation");
/**
 * This function validates the inputs of a GET request on /auth
 */
function validateGetAuthInput(parameters) {
    if (parameters) {
        if (parameters["Authorization"] &&
            !(0, basicValidation_1.validateAuthorization)(parameters["Authorization"])) {
            validateGetAuthInput.errors = basicValidation_1.validateAuthorization.errors;
            return false;
        }
        if (parameters["X-Real-IP"] &&
            !(0, basicValidation_1.validateXRealIP)(parameters["X-Real-IP"])) {
            validateGetAuthInput.errors = basicValidation_1.validateXRealIP.errors;
            return false;
        }
        if (parameters["X-Forwarded-Proto"] &&
            !(0, basicValidation_1.validateXForwardedProto)(parameters["X-Forwarded-Proto"])) {
            validateGetAuthInput.errors = basicValidation_1.validateXForwardedProto.errors;
            return false;
        }
    }
    return true;
}
exports.validateGetAuthInput = validateGetAuthInput;
/**
 * This function validates the outputs to a GET request on /auth
 */
function validateGetAuthOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (response.headers) {
            if (response.headers["Authorization"] &&
                !(0, basicValidation_1.validateGetAuthHeaderAuthorization)(response.headers["Authorization"])) {
                validateGetAuthOutput.errors = basicValidation_1.validateGetAuthHeaderAuthorization.errors;
                return false;
            }
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetAuthOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateGetAuthOutput = validateGetAuthOutput;
/**
 * This function validates the inputs of a POST request on /login
 */
function validatePostLoginInput(body) {
    if (!(0, basicValidation_1.validatePostLoginRequestBody)(body)) {
        validatePostLoginInput.errors = basicValidation_1.validatePostLoginRequestBody.errors;
        return false;
    }
    return true;
}
exports.validatePostLoginInput = validatePostLoginInput;
/**
 * This function validates the outputs to a POST request on /login
 */
function validatePostLoginOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (!(0, basicValidation_1.validatePostLoginResponse201)(response.body)) {
            validatePostLoginOutput.errors = basicValidation_1.validatePostLoginResponse201.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostLoginOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePostLoginOutput = validatePostLoginOutput;
/**
 * This function validates the inputs of a POST request on /logout
 */
function validatePostLogoutInput(body) {
    if (!(0, basicValidation_1.validatePostLogoutRequestBody)(body)) {
        validatePostLogoutInput.errors = basicValidation_1.validatePostLogoutRequestBody.errors;
        return false;
    }
    return true;
}
exports.validatePostLogoutInput = validatePostLogoutInput;
/**
 * This function validates the outputs to a POST request on /logout
 */
function validatePostLogoutOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostLogoutOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePostLogoutOutput = validatePostLogoutOutput;
/**
 * This function validates the inputs of a POST request on /device_authentication_token
 */
function validatePostDeviceAuthenticationTokenInput(parameters) {
    if (parameters) {
        if (!(0, basicValidation_1.validateDeviceUrl)(parameters["device_url"])) {
            validatePostDeviceAuthenticationTokenInput.errors = basicValidation_1.validateDeviceUrl.errors;
            return false;
        }
    }
    return true;
}
exports.validatePostDeviceAuthenticationTokenInput = validatePostDeviceAuthenticationTokenInput;
/**
 * This function validates the outputs to a POST request on /device_authentication_token
 */
function validatePostDeviceAuthenticationTokenOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validatePostDeviceAuthenticationTokenResponse200)(response.body)) {
            validatePostDeviceAuthenticationTokenOutput.errors = basicValidation_1.validatePostDeviceAuthenticationTokenResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostDeviceAuthenticationTokenOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePostDeviceAuthenticationTokenOutput = validatePostDeviceAuthenticationTokenOutput;
/**
 * This function validates the inputs of a GET request on /users
 */
function validateGetUsersInput() {
    return true;
}
exports.validateGetUsersInput = validateGetUsersInput;
/**
 * This function validates the outputs to a GET request on /users
 */
function validateGetUsersOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validateGetUsersResponse200)(response.body)) {
            validateGetUsersOutput.errors = basicValidation_1.validateGetUsersResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetUsersOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateGetUsersOutput = validateGetUsersOutput;
/**
 * This function validates the inputs of a POST request on /users
 */
function validatePostUsersInput(body) {
    if (body && !(0, basicValidation_1.validatePostUsersRequestBody)(body)) {
        validatePostUsersInput.errors = basicValidation_1.validatePostUsersRequestBody.errors;
        return false;
    }
    return true;
}
exports.validatePostUsersInput = validatePostUsersInput;
/**
 * This function validates the outputs to a POST request on /users
 */
function validatePostUsersOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (!(0, basicValidation_1.validatePostUsersResponse201)(response.body)) {
            validatePostUsersOutput.errors = basicValidation_1.validatePostUsersResponse201.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePostUsersOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePostUsersOutput = validatePostUsersOutput;
/**
 * This function validates the inputs of a GET request on /users/{username}
 */
function validateGetUsersByUsernameInput(parameters) {
    if (parameters) {
        if (!(0, basicValidation_1.validateUsername)(parameters["username"])) {
            validateGetUsersByUsernameInput.errors = basicValidation_1.validateUsername.errors;
            return false;
        }
    }
    return true;
}
exports.validateGetUsersByUsernameInput = validateGetUsersByUsernameInput;
/**
 * This function validates the outputs to a GET request on /users/{username}
 */
function validateGetUsersByUsernameOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validateGetUsersByUsernameResponse200)(response.body)) {
            validateGetUsersByUsernameOutput.errors = basicValidation_1.validateGetUsersByUsernameResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetUsersByUsernameOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateGetUsersByUsernameOutput = validateGetUsersByUsernameOutput;
/**
 * This function validates the inputs of a PATCH request on /users/{username}
 */
function validatePatchUsersByUsernameInput(parameters, body) {
    if (parameters) {
        if (!(0, basicValidation_1.validateUsername)(parameters["username"])) {
            validatePatchUsersByUsernameInput.errors = basicValidation_1.validateUsername.errors;
            return false;
        }
    }
    if (body && !(0, basicValidation_1.validatePatchUsersByUsernameRequestBody)(body)) {
        validatePatchUsersByUsernameInput.errors = basicValidation_1.validatePatchUsersByUsernameRequestBody.errors;
        return false;
    }
    return true;
}
exports.validatePatchUsersByUsernameInput = validatePatchUsersByUsernameInput;
/**
 * This function validates the outputs to a PATCH request on /users/{username}
 */
function validatePatchUsersByUsernameOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validatePatchUsersByUsernameResponse200)(response.body)) {
            validatePatchUsersByUsernameOutput.errors = basicValidation_1.validatePatchUsersByUsernameResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePatchUsersByUsernameOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePatchUsersByUsernameOutput = validatePatchUsersByUsernameOutput;
/**
 * This function validates the inputs of a DELETE request on /users/{username}
 */
function validateDeleteUsersByUsernameInput(parameters) {
    if (parameters) {
        if (!(0, basicValidation_1.validateUsername)(parameters["username"])) {
            validateDeleteUsersByUsernameInput.errors = basicValidation_1.validateUsername.errors;
            return false;
        }
    }
    return true;
}
exports.validateDeleteUsersByUsernameInput = validateDeleteUsersByUsernameInput;
/**
 * This function validates the outputs to a DELETE request on /users/{username}
 */
function validateDeleteUsersByUsernameOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateDeleteUsersByUsernameOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateDeleteUsersByUsernameOutput = validateDeleteUsersByUsernameOutput;
/**
 * This function validates the inputs of a PUT request on /users/{username}/roles/{role_name}
 */
function validatePutUsersByUsernameRolesByRoleNameInput(parameters) {
    if (parameters) {
        if (!(0, basicValidation_1.validateUsername)(parameters["username"])) {
            validatePutUsersByUsernameRolesByRoleNameInput.errors = basicValidation_1.validateUsername.errors;
            return false;
        }
        if (!(0, basicValidation_1.validateRoleName)(parameters["role_name"])) {
            validatePutUsersByUsernameRolesByRoleNameInput.errors = basicValidation_1.validateRoleName.errors;
            return false;
        }
    }
    return true;
}
exports.validatePutUsersByUsernameRolesByRoleNameInput = validatePutUsersByUsernameRolesByRoleNameInput;
/**
 * This function validates the outputs to a PUT request on /users/{username}/roles/{role_name}
 */
function validatePutUsersByUsernameRolesByRoleNameOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validatePutUsersByUsernameRolesByRoleNameResponse200)(response.body)) {
            validatePutUsersByUsernameRolesByRoleNameOutput.errors = basicValidation_1.validatePutUsersByUsernameRolesByRoleNameResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePutUsersByUsernameRolesByRoleNameOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePutUsersByUsernameRolesByRoleNameOutput = validatePutUsersByUsernameRolesByRoleNameOutput;
/**
 * This function validates the inputs of a DELETE request on /users/{username}/roles/{role_name}
 */
function validateDeleteUsersByUsernameRolesByRoleNameInput(parameters) {
    if (parameters) {
        if (!(0, basicValidation_1.validateUsername)(parameters["username"])) {
            validateDeleteUsersByUsernameRolesByRoleNameInput.errors =
                basicValidation_1.validateUsername.errors;
            return false;
        }
        if (!(0, basicValidation_1.validateRoleName)(parameters["role_name"])) {
            validateDeleteUsersByUsernameRolesByRoleNameInput.errors =
                basicValidation_1.validateRoleName.errors;
            return false;
        }
    }
    return true;
}
exports.validateDeleteUsersByUsernameRolesByRoleNameInput = validateDeleteUsersByUsernameRolesByRoleNameInput;
/**
 * This function validates the outputs to a DELETE request on /users/{username}/roles/{role_name}
 */
function validateDeleteUsersByUsernameRolesByRoleNameOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateDeleteUsersByUsernameRolesByRoleNameOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateDeleteUsersByUsernameRolesByRoleNameOutput = validateDeleteUsersByUsernameRolesByRoleNameOutput;
/**
 * This function validates the inputs of a GET request on /identity
 */
function validateGetIdentityInput() {
    return true;
}
exports.validateGetIdentityInput = validateGetIdentityInput;
/**
 * This function validates the outputs to a GET request on /identity
 */
function validateGetIdentityOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validateGetIdentityResponse200)(response.body)) {
            validateGetIdentityOutput.errors = basicValidation_1.validateGetIdentityResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validateGetIdentityOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validateGetIdentityOutput = validateGetIdentityOutput;
/**
 * This function validates the inputs of a PATCH request on /identity
 */
function validatePatchIdentityInput(body) {
    if (body && !(0, basicValidation_1.validatePatchIdentityRequestBody)(body)) {
        validatePatchIdentityInput.errors = basicValidation_1.validatePatchIdentityRequestBody.errors;
        return false;
    }
    return true;
}
exports.validatePatchIdentityInput = validatePatchIdentityInput;
/**
 * This function validates the outputs to a PATCH request on /identity
 */
function validatePatchIdentityOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!(0, basicValidation_1.validatePatchIdentityResponse200)(response.body)) {
            validatePatchIdentityOutput.errors = basicValidation_1.validatePatchIdentityResponse200.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    if (response.status === 403) {
        return true;
    }
    if (response.status === 404) {
        return true;
    }
    if (response.status === 500) {
        return true;
    }
    validatePatchIdentityOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
exports.validatePatchIdentityOutput = validatePatchIdentityOutput;
//# sourceMappingURL=requestValidation.js.map