#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.allowlist = void 0;
const config_1 = require("./config");
const data_source_1 = require("./data_source");
const generated_1 = require("./generated");
const model_1 = require("./model");
const utils_1 = require("./methods/utils");
const service_common_1 = require("@crosslab/service-common");
exports.allowlist = {};
async function resolveAllowlist() {
    for (const entry of config_1.config.ALLOWLIST) {
        try {
            const result = await (0, utils_1.resolveAllowlistEntry)(entry);
            exports.allowlist[result[0]] = result[1];
        }
        catch (error) {
            console.error(error);
        }
    }
}
data_source_1.AppDataSource.initialize()
    .then(async () => {
    await (0, data_source_1.initializeDataSource)();
    // Resolve Allowlist
    resolveAllowlist();
    setInterval(resolveAllowlist, 600000);
    // Create new active key
    const activeKeyRepository = data_source_1.AppDataSource.getRepository(model_1.ActiveKeyModel);
    const key = await (0, utils_1.generateNewKey)();
    const jwks = JSON.stringify({ keys: [(0, utils_1.jwk)(key)] });
    for (const activeKey of await activeKeyRepository.find()) {
        await activeKeyRepository.delete(activeKey);
    }
    const activeKey = activeKeyRepository.create();
    activeKey.key = key;
    activeKey.use = key.use;
    await activeKeyRepository.save(activeKey);
    generated_1.app.get('/.well-known/jwks.json', (_req, res, _next) => {
        res.send(jwks);
    });
    generated_1.app.get('/.well-known/openid-configuration', (_req, res, _next) => {
        res.send({ jwks_uri: '/.well-known/jwks.json' });
    });
    generated_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config),
            AccessToken: (_req, _scopes) => {
                throw new Error('Not Implemented');
            },
            TuiAuth: (_req, _scopes) => {
                throw new Error('Not implemented');
            }
        }
    });
    generated_1.app.listen(config_1.config.PORT);
    console.log('Initialization finished');
})
    .catch((error) => {
    console.error('Error during Data Source initialization:', error);
});
//# sourceMappingURL=index.js.map