"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDeviceAuthenticationToken = void 0;
const data_source_1 = require("../data_source");
const api_1 = require("../methods/api");
const model_1 = require("../model");
const errors_1 = require("../types/errors");
/**
 * This function implements the functionality for handling POST requests on /device_token endpoint.
 * @param parameters The parameters of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Could not find user.
 */
const postDeviceAuthenticationToken = async (parameters, user) => {
    console.log(`postDeviceAuthenticationToken called`);
    const userRepository = data_source_1.AppDataSource.getRepository(model_1.UserModel);
    const userModel = await userRepository.findOne({
        where: {
            username: user.JWT?.username,
        },
        relations: {
            tokens: true,
        },
    });
    if (!userModel)
        throw new errors_1.MissingEntityError(`Could not find user ${user.JWT?.username}`, 404);
    const device = await (0, api_1.getDevice)(parameters.device_url);
    if (device.owner != user.JWT?.url)
        throw new errors_1.OwnershipError();
    const tokenRepository = data_source_1.AppDataSource.getRepository(model_1.TokenModel);
    const token = tokenRepository.create();
    token.device = device.url;
    userModel.tokens.push(token);
    await userRepository.save(userModel);
    console.log(`postDeviceAuthenticationToken succeeded`);
    return {
        status: 200,
        body: token.token,
    };
};
exports.postDeviceAuthenticationToken = postDeviceAuthenticationToken;
//# sourceMappingURL=device_authentication_token.js.map