"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchIdentity = exports.getIdentity = void 0;
const data_source_1 = require("../data_source");
const model_1 = require("../model");
const errors_1 = require("../types/errors");
const format_1 = require("../methods/format");
const write_1 = require("../methods/write");
/**
 * This function implements the functionality for handling GET requests on /identity endpoint.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user is not found in database.
 */
const getIdentity = async (user) => {
    console.log(`getIdentity called`);
    const userRepository = data_source_1.AppDataSource.getRepository(model_1.UserModel);
    const userModel = await userRepository.findOne({
        where: {
            username: user.JWT?.username,
        },
        relations: {
            roles: {
                scopes: true,
            },
        },
    });
    if (!userModel)
        throw new errors_1.MissingEntityError(`Could not find user ${user.JWT?.username}`, 404);
    console.log(`getIdentity succeeded`);
    return {
        status: 200,
        body: (0, format_1.formatUser)(userModel),
    };
};
exports.getIdentity = getIdentity;
/**
 * This function implements the functionality for handling PATCH requests on /identity endpoint.
 * @param body The body of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user is not found in database.
 * @throws {InvalidValueError} Can throw errors from {@link writeUser}.
 */
const patchIdentity = async (body, user) => {
    console.log(`patchIdentity called`);
    const userRepository = data_source_1.AppDataSource.getRepository(model_1.UserModel);
    const userModel = await userRepository.findOneBy({ username: user.JWT?.username });
    if (!userModel)
        throw new errors_1.MissingEntityError(`Could not find user ${user.JWT?.username}`, 404);
    await (0, write_1.writeUser)(userModel, body ?? {});
    await userRepository.save(userModel);
    console.log(`patchIdentity succeeded`);
    return {
        status: 200,
        body: (0, format_1.formatUser)(userModel),
    };
};
exports.patchIdentity = patchIdentity;
//# sourceMappingURL=identity.js.map