"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postLogin = void 0;
const errors_1 = require("../types/errors");
const login_1 = require("../methods/login");
/**
 * This function implements the functionality for handling POST requests on /login endpoint.
 * @param body The body of the request.
 * @throws {LdapBindError} Can throw errors from {@link loginTui}.
 * @throws {LdapError} Can throw errors from {@link loginTui}.
 * @throws {AuthenticationError} Thrown if the authentication was unsuccessful.
 */
const postLogin = async (body) => {
    console.log(`postLogin called for ${body.username} using method ${body.method}`);
    let token;
    try {
        switch (body.method) {
            case 'local':
                token = await (0, login_1.loginLocal)(body.username, body.password);
                break;
            case 'tui':
                token = await (0, login_1.loginTui)(body.username, body.password);
                break;
        }
    }
    catch (error) {
        // LdapAuthenticationError -> AuthenticationError
        if (error instanceof errors_1.LdapAuthenticationError) {
            throw new errors_1.AuthenticationError(`Invalid login credentials`, 401);
        }
        throw error;
    }
    if (!token)
        throw new errors_1.AuthenticationError(`Authentication failed`, 401);
    console.log(`postLogin succeeded`);
    return {
        status: 201,
        body: token.token,
    };
};
exports.postLogin = postLogin;
//# sourceMappingURL=login.js.map