"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postLogout = void 0;
const data_source_1 = require("../data_source");
const model_1 = require("../model");
const errors_1 = require("../types/errors");
/**
 * This function implements the functionality for handling POST requests on /logout endpoint.
 * @param body The body of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user or token is not found in the database.
 */
const postLogout = async (body, user) => {
    console.log(`postLogout called for ${user.JWT?.username}`);
    const userRepository = data_source_1.AppDataSource.getRepository(model_1.UserModel);
    const userModel = await userRepository.findOne({
        where: {
            username: user.JWT?.username,
        },
        relations: {
            tokens: true,
        },
    });
    if (!userModel)
        throw new errors_1.MissingEntityError(`Could not find user ${user.JWT?.username}`, 404);
    const token = userModel.tokens.find((t) => t.token === body.token);
    if (!token)
        throw new errors_1.MissingEntityError(`Could not find requested token in tokens of user ${user.JWT?.username}`, 404);
    userModel.tokens = userModel.tokens.filter((t) => t.token !== body.token);
    await userRepository.save(userModel);
    console.log(`postLogout succeeded`);
    return {
        status: 200,
    };
};
exports.postLogout = postLogout;
//# sourceMappingURL=logout.js.map