"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OwnershipError = exports.InternalRequestError = exports.LdapBindError = exports.LdapAuthenticationError = exports.LdapError = exports.AuthenticationError = exports.InconsistentDatabaseError = exports.ExpiredError = exports.MalformedAllowlistEntryError = exports.InvalidValueError = exports.MissingEntityError = exports.DNSResolveError = void 0;
const types_1 = require("../generated/types");
/**
 * This error class should be used if an error occurrs while resolving the ip of a domain.
 */
class DNSResolveError extends Error {
    constructor(message) {
        super(message);
        this.name = 'DNSResolveError';
    }
}
exports.DNSResolveError = DNSResolveError;
/**
 * This error class should be used if an entity is not found in the database.
 */
class MissingEntityError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingEntityError';
    }
}
exports.MissingEntityError = MissingEntityError;
/**
 * This error class should be used if an object contains an invalid value.
 */
class InvalidValueError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidValueError';
    }
}
exports.InvalidValueError = InvalidValueError;
/**
 * This error class should be used if an entry of the allowlist is malformed.
 */
class MalformedAllowlistEntryError extends Error {
    constructor(message) {
        super(message);
        this.name = 'MalformedAllowlistEntryError';
    }
}
exports.MalformedAllowlistEntryError = MalformedAllowlistEntryError;
/**
 * This error class should be used if an object has expired.
 */
class ExpiredError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ExpiredError';
    }
}
exports.ExpiredError = ExpiredError;
/**
 * This error class should be used if there is an inconsitency in the database.
 */
class InconsistentDatabaseError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InconsistentDatabaseError';
    }
}
exports.InconsistentDatabaseError = InconsistentDatabaseError;
/**
 * This error class should be used if an error occurs during authentication.
 */
class AuthenticationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'AuthenticationError';
    }
}
exports.AuthenticationError = AuthenticationError;
/**
 * This error class should be used if an error occurs whilst using the ldap system.
 */
class LdapError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'LdapError';
    }
}
exports.LdapError = LdapError;
/**
 * This error class should be used if an error occurs during the authentication to the ldap system.
 */
class LdapAuthenticationError extends LdapError {
    constructor(message, status) {
        super(message, status);
        this.name = 'LdapAuthenticationError';
    }
}
exports.LdapAuthenticationError = LdapAuthenticationError;
/**
 * This error class should be used if an error occurs during the bind operation of the ldap system.
 */
class LdapBindError extends LdapError {
    constructor(message, status) {
        super(message, status);
        this.name = 'LdapBindError';
    }
}
exports.LdapBindError = LdapBindError;
/**
 * This error class should be used as a wrapper for errors thrown by the api-client.
 */
class InternalRequestError extends types_1.ErrorWithStatus {
    constructor(message, error, status) {
        super(message, status);
        this.name = 'InternalRequestError';
        this.internalError = error;
    }
}
exports.InternalRequestError = InternalRequestError;
/**
 * This error class should be used when an user is not the owner of a device.
 */
class OwnershipError extends types_1.ErrorWithStatus {
    constructor() {
        super(`User is not the owner of the device`, 403);
        this.name = 'OwnershipError';
    }
}
exports.OwnershipError = OwnershipError;
//# sourceMappingURL=errors.js.map